from __future__ import absolute_import

# flake8: noqa

# import apis into api package
from stencila.hub.api.accounts_api import AccountsApi
from stencila.hub.api.invites_api import InvitesApi
from stencila.hub.api.jobs_api import JobsApi
from stencila.hub.api.projects_api import ProjectsApi
from stencila.hub.api.status_api import StatusApi
from stencila.hub.api.tokens_api import TokensApi
from stencila.hub.api.users_api import UsersApi
from stencila.hub.api.workers_api import WorkersApi



# coding: utf-8

# flake8: noqa
"""
    Stencila Hub API

    ## Authentication  Many endpoints in the Stencila Hub API require an authentication token. These tokens carry many privileges, so be sure to keep them secure. Do not place your tokens in publicly accessible areas such as client-side code. The API is only served over HTTPS to avoid exposing tokens and other data on the network.  To obtain a token, [`POST /api/tokens`](#operations-tokens-tokens_create) with either a `username` and `password` pair, or an [OpenID Connect](https://openid.net/connect/) token. Then use the token in the `Authorization` header of subsequent requests with the prefix `Token` e.g.      curl -H \"Authorization: Token 48866b1e38a2e9db0baada2140b2327937f4a3636dd5f2dfd8c212341c88d34\" https://hub.stenci.la/api/projects/  Alternatively, you can use `Basic` authentication with the token used as the username and no password. This can be more convenient when using command line tools such as [cURL](https://curl.haxx.se/) e.g.      curl -u 48866b1e38a2e9db0baada2140b2327937f4a3636dd5f2dfd8c212341c88d34: https://hub.stenci.la/api/projects/  Or, the less ubiquitous, but more accessible [httpie](https://httpie.org/):      http --auth 48866b1e38a2e9db0baada2140b2327937f4a3636dd5f2dfd8c212341c88d34: https://hub.stenci.la/api/projects/  In both examples above, the trailing colon is not required but avoids being asked for a password.  ## Versioning  The Stencila Hub is released using semantic versioning. The current version is available from the [`GET /api/status`](/api/status) endpoint. Please see the [Github release page](https://github.com/stencila/hub/releases) and the [changelog](https://github.com/stencila/hub/blob/master/CHANGELOG.md) for details on each release. We currently do not provide versioning of the API but plan to do so soon (probably by using a `Accept: application/vnd.stencila.hub+json;version=1.0` request header). If you are using, or interested in using, the API please contact us and we may be able to expedite this.   # noqa: E501

    The version of the OpenAPI document: v1
    Contact: hello@stenci.la
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from stencila.hub.models.account_create import AccountCreate
from stencila.hub.models.account_list import AccountList
from stencila.hub.models.account_retrieve import AccountRetrieve
from stencila.hub.models.account_team import AccountTeam
from stencila.hub.models.account_update import AccountUpdate
from stencila.hub.models.account_user import AccountUser
from stencila.hub.models.file import File
from stencila.hub.models.file_list import FileList
from stencila.hub.models.inline_object import InlineObject
from stencila.hub.models.inline_object1 import InlineObject1
from stencila.hub.models.inline_object2 import InlineObject2
from stencila.hub.models.inline_object3 import InlineObject3
from stencila.hub.models.inline_object4 import InlineObject4
from stencila.hub.models.inline_object5 import InlineObject5
from stencila.hub.models.inline_response200 import InlineResponse200
from stencila.hub.models.inline_response2001 import InlineResponse2001
from stencila.hub.models.inline_response20010 import InlineResponse20010
from stencila.hub.models.inline_response20011 import InlineResponse20011
from stencila.hub.models.inline_response20011_results import InlineResponse20011Results
from stencila.hub.models.inline_response20012 import InlineResponse20012
from stencila.hub.models.inline_response20013 import InlineResponse20013
from stencila.hub.models.inline_response20014 import InlineResponse20014
from stencila.hub.models.inline_response20015 import InlineResponse20015
from stencila.hub.models.inline_response2002 import InlineResponse2002
from stencila.hub.models.inline_response2003 import InlineResponse2003
from stencila.hub.models.inline_response2004 import InlineResponse2004
from stencila.hub.models.inline_response2005 import InlineResponse2005
from stencila.hub.models.inline_response2006 import InlineResponse2006
from stencila.hub.models.inline_response2007 import InlineResponse2007
from stencila.hub.models.inline_response2008 import InlineResponse2008
from stencila.hub.models.inline_response2009 import InlineResponse2009
from stencila.hub.models.inline_response201 import InlineResponse201
from stencila.hub.models.invite import Invite
from stencila.hub.models.job import Job
from stencila.hub.models.me import Me
from stencila.hub.models.project import Project
from stencila.hub.models.project_agent import ProjectAgent
from stencila.hub.models.project_agent_update import ProjectAgentUpdate
from stencila.hub.models.project_create import ProjectCreate
from stencila.hub.models.project_list import ProjectList
from stencila.hub.models.project_update import ProjectUpdate
from stencila.hub.models.queue import Queue
from stencila.hub.models.snapshot import Snapshot
from stencila.hub.models.source import Source
from stencila.hub.models.status_response import StatusResponse
from stencila.hub.models.token import Token
from stencila.hub.models.user import User
from stencila.hub.models.worker import Worker
from stencila.hub.models.worker_heartbeat import WorkerHeartbeat
from stencila.hub.models.zone import Zone
